from setuptools import setup

setup(
    name='helium-orbital',
    version='0.0.1',
    description='',
    long_description='',
    url='',
    author='Crypto Balloon LLC',
    author_email='joshua@cryptoballoon.net',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)